==> tomcat8_8.5.39.orig.tar.xz: tomcat8-8.5.39/test/org/apache/tomcat/util/res/TestStringManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tomcat.util.res;

import org.junit.Assert;
import org.junit.Test;

public class TestStringManager {

    private static final StringManager sm =
        StringManager.getManager("org.apache.naming");

    @Test
    public void testNullKey() {
        boolean iaeThrown = false;

        try {
            sm.getString(null);
        } catch (IllegalArgumentException iae) {
            iaeThrown = true;
        }
        Assert.assertTrue("IAE not thrown on null key", iaeThrown);
    }

    @Test
    public void testBug46933() {
        // Check null args are OK
        sm.getString("namingContext.nameNotBound");
        sm.getString("namingContext.nameNotBound", (Object[]) null);
        sm.getString("namingContext.nameNotBound", new Object[1]);
    }
}

==> tomcat8_8.5.54.orig.tar.xz: tomcat8-8.5.54/test/org/apache/tomcat/util/res/TestStringManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tomcat.util.res;

import java.util.Locale;

import org.junit.Assert;
import org.junit.Test;

public class TestStringManager {

    private static final String PACKAGE_NAME = "org.apache.tomcat.util";
    private static final StringManager sm = StringManager.getManager(PACKAGE_NAME);

    @Test
    public void testNullKey() {
        boolean iaeThrown = false;

        try {
            sm.getString(null);
        } catch (IllegalArgumentException iae) {
            iaeThrown = true;
        }
        Assert.assertTrue("IAE not thrown on null key", iaeThrown);
    }

    @Test
    public void testBug46933() {
        // Check null args are OK
        sm.getString("namingContext.nameNotBound");
        sm.getString("namingContext.nameNotBound", (Object[]) null);
        sm.getString("namingContext.nameNotBound", new Object[1]);
    }

    @Test
    public void testFrench() {
        StringManager sm = StringManager.getManager(PACKAGE_NAME, Locale.FRENCH);
        Assert.assertEquals(Locale.FRENCH, sm.getLocale());
    }

    @Test
    public void testMissing() {
        Thread.currentThread().setContextClassLoader(TestStringManager.class.getClassLoader());
        StringManager sm = StringManager.getManager("org.does.no.exist");
        Assert.assertNull(sm.getLocale());
    }

}
